RelativeEntityUpdate

Struct RelativeEntityUpdate 

pub struct RelativeEntityUpdate {
    pub partial_world: Arc<RwLock<RawRwLock, PartialWorld>>,
    pub update: Box<dyn FnOnce(&mut EntityWorldMut<'_>) + Send + Sync>,
}
An [EntityCommand] that applies a “relative update” to an entity, which means this update won’t be run multiple times by different clients in the same world.

This is used to avoid a bug where when there’s multiple clients in the same world and an entity sends a relative move packet to all clients, its position gets desynced since the relative move is applied multiple times.

Don’t use this unless you actually got an entity update packet that all other clients within render distance will get too. You usually don’t need this when the change isn’t relative either.

Fields

partial_world: Arc<RwLock<RawRwLock, PartialWorld>>update: Box<dyn FnOnce(&mut EntityWorldMut<'_>) + Send + Sync>

Implementations



impl RelativeEntityUpdate

pub fn new( partial_world: Arc<RwLock<RawRwLock, PartialWorld>>, update: impl FnOnce(&mut EntityWorldMut<'_>) + Send + Sync + 'static, ) -> RelativeEntityUpdate