Struct UpdatesReceived
pub struct UpdatesReceived(/* private fields */);Expand description
A component that counts the number of times this entity has been modified.
This is used for making sure two clients don’t do the same relative update on an entity.
If an entity is local (i.e. it’s a client/LocalEntity), this component should NOT be present in the entity.